0.2.1 (2023-01-06)
------------------

Fixed a bad spam filter bug leading to comments being classified as ham which have lots of unknown words.

* fixed comment posting (min instead of slim jquery dependency)
* api overview is working again
